package com.ruoyi.abuwx.controller;

import com.ruoyi.abuwx.domain.WbProject;
import com.ruoyi.abuwx.service.IWbProjectService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 项目管理Controller
 *
 * @author ruoyi
 * @date 2024-04-08
 */
@RestController
@RequestMapping("/abuwx/project")
public class WbProjectController extends BaseController
{
    @Autowired
    private IWbProjectService wbProjectService;

    /**
     * 查询项目管理列表
     */
    @PreAuthorize("@ss.hasPermi('abuwx:project:list')")
    @GetMapping("/list")
    public TableDataInfo list(WbProject wbProject)
    {
        startPage();
        List<WbProject> list = wbProjectService.selectWbProjectList(wbProject);
        return getDataTable(list);
    }

    /**
     * 导出项目管理列表
     */
    @PreAuthorize("@ss.hasPermi('abuwx:project:export')")
    @Log(title = "项目管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WbProject wbProject)
    {
        List<WbProject> list = wbProjectService.selectWbProjectList(wbProject);
        ExcelUtil<WbProject> util = new ExcelUtil<WbProject>(WbProject.class);
        util.exportExcel(response, list, "项目管理数据");
    }

    /**
     * 获取项目管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('abuwx:project:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wbProjectService.selectWbProjectById(id));
    }

    /**
     * 新增项目管理
     */
    @PreAuthorize("@ss.hasPermi('abuwx:project:add')")
    @Log(title = "项目管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WbProject wbProject)
    {
        return toAjax(wbProjectService.insertWbProject(wbProject));
    }

    /**
     * 修改项目管理
     */
    @PreAuthorize("@ss.hasPermi('abuwx:project:edit')")
    @Log(title = "项目管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WbProject wbProject)
    {
        return toAjax(wbProjectService.updateWbProject(wbProject));
    }

    /**
     * 删除项目管理
     */
    @PreAuthorize("@ss.hasPermi('abuwx:project:remove')")
    @Log(title = "项目管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wbProjectService.deleteWbProjectByIds(ids));
    }
}
